@@ -1,9 +1,9 @@
 import swem
 
-from gensim.models import Word2Vec
+from gensim.models import KeyedVectors
 
 if __name__ == '__main__':
-    model = Word2Vec.load('wiki_mecab-ipadic-neologd.model')
+    model = KeyedVectors.load('wiki_mecab-ipadic-neologd.kv')
     swem_embed = swem.SWEM(model, lang='en')
 
     doc = 'This is an implementation of SWEM.'
