@@ -8,14 +8,14 @@ from swem import tokenizers
 
 def _word_embed(
     token: str,
-    wv: Word2VecKeyedVectors,
+    kv: Word2VecKeyedVectors,
     uniform_range: Tuple[float, ...] = (-0.01, 0.01)
 ) -> np.ndarray:
-    """ Get word embeddings of given token.
+    """ Get word embedding of given token.
 
     Args:
         token (str): A word token to embed.
-        wv (Word2VecKeyedVectors): Vocabularies dictionary.
+        kv (Word2VecKeyedVectors): Vocabularies dictionary.
         uniform_range (Tuple[float, ...]): A range of uniform distribution to
                                            generate random vector.
 
@@ -23,10 +23,10 @@ def _word_embed(
         numpy.ndarray: An array with shape (self.embed_dim, )
     """
     try:
-        return wv[token]
+        return kv[token]
     except Exception as e:
         print(e)
-        embed_dim = wv.vector_size
+        embed_dim = kv.vector_size
         return np.random.uniform(
             uniform_range[0],
             uniform_range[1],
@@ -34,20 +34,21 @@ def _word_embed(
         )
 
 
-def _doc_embed(tokens: List[str], wv: Word2VecKeyedVectors,
-               uniform_range: Tuple[float, ...]) -> np.ndarray:
-    """ Get document embeddings of given tokens.
+def _word_embeds(tokens: List[str], kv: Word2VecKeyedVectors,
+                 uniform_range: Tuple[float, ...]) -> np.ndarray:
+    """ Get word embeddings of given tokens.
 
     Args:
         tokens (List[str]): A word tokens to calculate embeddding.
 
     Returns:
-        numpy.ndarray: An embedding array with shape (self.embed_dim, ).
+        numpy.ndarray: An embedding array with shape
+                       (token_size, self.embed_dim, ).
     """
     doc_embed = []
     for token in tokens:
         word_embed: np.ndarray = _word_embed(
-            token=token, wv=wv, uniform_range=uniform_range
+            token=token, kv=kv, uniform_range=uniform_range
         )
         doc_embed.append(word_embed)
     return np.array(doc_embed)
@@ -57,8 +58,7 @@ class SWEM:
     """Implementation of SWEM.
 
     Args:
-        model: gensim.models.word2vec.Word2Vec
-            Word2Vec model
+        kv: gensim.models.keyedvectors.Word2VecKeyedVectors
         tokenizer: Callable
             Callable object to tokenize input text.
         uniform_range: Tuple[float, ...]
@@ -66,9 +66,9 @@ class SWEM:
         lang (str): 'ja' or `en`. Default value is 'ja'.
     """
 
-    def __init__(self, model, tokenizer=None, uniform_range=(-0.01, 0.01),
+    def __init__(self, kv, tokenizer=None, uniform_range=(-0.01, 0.01),
                  lang: str = 'ja'):
-        self.model = model
+        self.kv = kv
         if tokenizer is None:
             if lang == 'ja':
                 tokenizer = tokenizers.tokenize_ja
@@ -124,9 +124,9 @@ class SWEM:
             numpy.ndarray: An embedding array.
         """
         tokens: List[str] = self.tokenizer(doc)
-        doc_embed: np.ndarray = _doc_embed(
+        doc_embed: np.ndarray = _word_embeds(
             tokens=tokens,
-            wv=self.model.wv,
+            kv=self.kv,
             uniform_range=self.uniform_range
         )
 
