@@ -8,43 +8,39 @@ from swem import models, tokenizers
 
 def test_word_embed():
     token = '私'
-    w2v = MockW2V()
-    embed = models._word_embed(token, wv=w2v.wv)
+    kv = MockKV()
+    embed = models._word_embed(token, kv=kv)
     assert embed.shape == (200, )
 
 
-def test_doc_embed():
+def test_word_embeds():
     tokens = ['私', 'は']
-    w2v = MockW2V()
-    embed = models._doc_embed(tokens, wv=w2v.wv, uniform_range=(-0.01, 0.01))
+    kv = MockKV()
+    embed = models._word_embeds(tokens, kv=kv, uniform_range=(-0.01, 0.01))
     assert embed.shape == (2, 200)
 
 
-class MockW2V:
+class MockKV:
 
-    class MockWV:
+    vector_size = 200
 
-        vector_size = 200
-
-        def __getitem__(self, item):
-            return np.zeros(self.vector_size)
-
-    wv = MockWV()
+    def __getitem__(self, item):
+        return np.zeros(self.vector_size)
 
 
 class SWEMTests(unittest.TestCase):
 
     def setUp(self):
-        self.swem = models.SWEM(MockW2V())
+        self.swem = models.SWEM(MockKV())
 
     def test_init_raise_lang(self):
         """ Chech ValueError for invalid lang passed. """
         with pytest.raises(ValueError):
-            models.SWEM(MockW2V(), lang='es')
+            models.SWEM(MockKV(), lang='es')
 
     def test_init_tokenizer_en(self):
         """ Passed lang='en', tokenizer equals to tokenize_en """
-        model = models.SWEM(MockW2V(), lang='en')
+        model = models.SWEM(MockKV(), lang='en')
         assert model.tokenizer == tokenizers.tokenize_en
 
     def test_infer_vector(self):
@@ -66,15 +62,15 @@ class SWEMTests(unittest.TestCase):
             self.swem.infer_vector(doc, method=method)
 
     def test_hierarchical_pool(self):
-        doc = 'すもももももももものうち'
-        doc_embed = models._doc_embed(doc, self.swem.model.wv, (-1, 1))
-        ret = self.swem._hierarchical_pool(doc_embed, n_windows=3)
+        text = 'すもももももももものうち'
+        word_embeds = models._word_embeds(text, self.swem.kv, (-1, 1))
+        ret = self.swem._hierarchical_pool(word_embeds, n_windows=3)
         assert ret.shape == (200, )
 
     def test_hierarchical_pool_raise(self):
         """ ValueError: when invalid n_windows passed. """
         doc = '桃'
-        doc_embed = models._doc_embed(doc, self.swem.model.wv, (-1, 1))
+        word_embeds = models._word_embeds(doc, self.swem.kv, (-1, 1))
         with pytest.raises(ValueError):
             # text_length: 1, n_windows: 3
-            self.swem._hierarchical_pool(doc_embed, n_windows=3)
+            self.swem._hierarchical_pool(word_embeds, n_windows=3)
